.. _examples:

Examples
========

Here we catalog all the example Jupyter notebooks that have been created
for the various functionality contained in `plasmapy`.

.. contents::
   :local:

.. _getting-started-notebooks:

Getting started
---------------

.. nbgallery::

   notebooks/getting_started/units
   notebooks/getting_started/particles

Analyses & Diagnostics
----------------------

.. nbgallery::
   :glob:

   notebooks/analysis/*
   notebooks/analysis/*/*
   notebooks/diagnostics/*

Dispersion
----------

.. nbgallery::
   :glob:

   notebooks/dispersion/*

Formulary
---------

.. nbgallery::
   :glob:

   notebooks/formulary/*

Particles
---------

.. nbgallery::
   :glob:

   notebooks/particles/*

Plasma Objects
--------------

.. nbgallery::
   :glob:

   notebooks/plasma/*

Simulation
----------

.. nbgallery::
   :glob:

   notebooks/simulation/*
